==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/EXTENSIBLEFRAMEWORKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EXTENSIBLEFRAMEWORKID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EXTENSIBLEFRAMEWORKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EFRFILENAME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTENSIBLEFRAMEWORKID_Type", propOrder = {
    "efrfilename"
})
public class EXTENSIBLEFRAMEWORKID_Type {

    @XmlElement(name = "EFRFILENAME", required = true)
    protected String efrfilename;

    /**
     * Obtient la valeur de la propriété efrfilename.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEFRFILENAME() {
        return efrfilename;
    }

    /**
     * Définit la valeur de la propriété efrfilename.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEFRFILENAME(String value) {
        this.efrfilename = value;
    }

}

==> eam-wshub-proxyclient-11.7-0-sources.jar: net/datastream/schemas/mp_fields/EXTENSIBLEFRAMEWORKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for EXTENSIBLEFRAMEWORKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EXTENSIBLEFRAMEWORKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EFRFILENAME"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EXTENSIBLEFRAMEWORKID_Type", propOrder = {
    "efrfilename"
})
public class EXTENSIBLEFRAMEWORKID_Type {

    @XmlElement(name = "EFRFILENAME", required = true)
    protected String efrfilename;

    /**
     * Gets the value of the efrfilename property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getEFRFILENAME() {
        return efrfilename;
    }

    /**
     * Sets the value of the efrfilename property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setEFRFILENAME(String value) {
        this.efrfilename = value;
    }

}
